All pastes #2335 Raw Edit

Anonymous

public text v1 · immutable
#2335 ·published 2004-11-25 14:13 UTC
rendered paste body
./post-commit
/home/forrest/repos/learnlinux/hooks/commit-email.pl: revision number `' must be an integer > 0.
usage: /home/forrest/repos/learnlinux/hooks/commit-email.pl REPOS REVNUM [[-m regex] [options] [email_addr ...]] ...
options are
  --from email_address  Email address for 'From:' (overrides -h)
  -h hostname           Hostname to append to author for 'From:'
  -l logfile            Append mail contents to this log file
  -m regex              Regular expression to match committed path
  -r email_address      Email address for 'Reply-To:'
  -s subject_prefix     Subject line prefix

This script supports a single repository with multiple projects,
where each project receives email only for commits that modify that
project.  A project is identified by using the -m command line
with a regular expression argument.  If a commit has a path that
matches the regular expression, then the entire commit matches.
Any of the following -h, -l, -r and -s command line options and
following email addresses are associated with this project.  The
next -m resets the -h, -l, -r and -s command line options and the
list of email addresses.

To support a single project conveniently, the script initializes
itself with an implicit -m . rule that matches any modifications
to the repository.  Therefore, to use the script for a single
project repository, just use the other comand line options and
a list of email addresses on the command line.  If you do not want
a project that matches the entire repository, then use a -m with a
regular expression before any other command line options or email
addresses.